@@ -136,6 +136,15 @@ class ApiObject(object):
         entry = self.internaluse_api.ALLOWED_PATHS.get(self.internaluse_path,
                                                        {})
         nocache = entry.get('nocache', False)
+        # special handling for projects/xxx/plan
+        if self.internaluse_path == 'project/plan/':
+            self.internaluse_path = 'project/%s/plan/' % (
+                self.internaluse_data['project'])
+        # special handling for projects/xxx/insurnace
+        if self.internaluse_path == 'project/insurance/':
+            self.internaluse_path = 'project/%s/insurance/' % (
+                self.internaluse_data['project'])
+
         if nocache or self._response is None:
             self._response = self.internaluse_api._make_request(
                 self.internaluse_path, self.internaluse_data)
@@ -189,6 +198,17 @@ class KavaApi(object):
             'accepts_company': True,
             'auth': 'basic',
             },
+        'project/plan/': {
+            'method': 'get',
+            'accepts_company': False,
+            'auth': 'api_key',
+        },
+        'project/insurance/': {
+            'method': 'get',
+            'accepts_company': False,
+            'auth': 'api_key',
+        },
+
         'kavauser/by_score/': {
             'method': 'post',
             'accepts_company': True,
@@ -200,6 +220,11 @@ class KavaApi(object):
             'auth': 'api_key',
             'nocache': True,
             },
+        'ticket/add/': {
+            'method': 'post',
+            'accepts_company': True,
+            'auth': 'basic',
+            },
 
         'project/': {
             'children_config': {
@@ -252,8 +277,13 @@ class KavaApi(object):
         requires_api_key = self.ALLOWED_PATHS.get(resource_uri, {}
                                                   ).get('auth') == 'api_key'
         # special case for /kavauser/username/
-        if resource_uri.split('/')[0] == 'kavauser':
-            if resource_uri.split('/')[1] != 'by_score':
+        split = resource_uri.split('/')
+        if split[0] == 'kavauser':
+            if split[1] != 'by_score':
+                requires_api_key = True
+        # case for /project/xxx/plan/ and /project/xxx/insurance/
+        if split[0] == 'project':
+            if len(split) > 2 and split[2] in ('plan', 'insurance'):
                 requires_api_key = True
 
         requests_method_kwargs = {data_key: data}
@@ -266,7 +296,7 @@ class KavaApi(object):
         else:
             requests_method_kwargs['auth'] = (self.username, self.password)
 
-        if resource_uri=='arbitrary_data/':  # EVIL HACK!!!
+        if resource_uri == 'arbitrary_data/':  # EVIL HACK!!!
             import json
             requests_method_kwargs[data_key] = json.dumps(data)
         response = requests_method(url, **requests_method_kwargs)
